@@ -26,7 +26,7 @@ make_image(Grs::Graph& graph, Grs::GridImage& image)
 
 #include <libgnomecanvasmm/init.h>
 #include <gtkmm/main.h>
-#include <grs/buttonbox.h>
+#include <grs/buttonboxwindow.h>
 
 #include <boost/bind.hpp>
 using boost::bind;
