@@ -1,4 +1,4 @@
-/* $Id: buttonbox.cc 38 2003-12-20 15:23:59Z takekawa $
+/* $Id: buttonbox.cc 53 2004-01-12 19:17:04Z takekawa $
  * Copyright (C) 2003 Takashi Takekawa
  * This file is part of the Grs Library
  *
@@ -88,60 +88,4 @@ ButtonBox::add_file_selection(const char* name,
     pack_start(*button, Gtk::PACK_SHRINK);
 }
 
-
-ButtonBoxWindow::ButtonBoxWindow(const char* title)
-    : Gtk::Window(), m_list()
-{
-    set_title(title);
-    add(m_list);
-}
-
-ButtonBoxWindow::~ButtonBoxWindow()
-{
-}
-
-void
-ButtonBoxWindow::add_window(Gtk::Window& window)
-{
-    m_list.add_window(window);
-}
-
-void
-ButtonBoxWindow::add_func(const char* name, const boost::function<void()>& function)
-{
-    m_list.add_func(name, function);
-}
-
-void
-ButtonBoxWindow::add_toggle(const char* name, const boost::function<void(bool)>& function)
-{
-    m_list.add_toggle(name, function);
-}
-
-void
-ButtonBoxWindow::add_toggle(const char* name,
-        const boost::function<void()>& on, const boost::function<void()>& off)
-{
-    m_list.add_toggle(name, on, off);
-}
-
-void
-ButtonBoxWindow::add_toggle(const char* name, Property<bool>& flag)
-{
-    m_list.add_toggle(name, flag);
-}
-
-void
-ButtonBoxWindow::add_thread(const char* name, const boost::function<bool()>& function)
-{
-    m_list.add_thread(name, function);
-}
-
-void
-ButtonBoxWindow::add_file_selection(const char* name,
-        const boost::function<bool(const char*)>& function)
-{
-    m_list.add_file_selection(name, function);
-}
-
 }
