@@ -1,4 +1,4 @@
-/* $Id: buttonbox.h 38 2003-12-20 15:23:59Z takekawa $
+/* $Id: buttonbox.h 53 2004-01-12 19:17:04Z takekawa $
  * Copyright (C) 2003 Takashi Takekawa
  * This file is part of the Grs Library
  *
@@ -51,32 +51,6 @@ public:
             const boost::function<bool(const char*)>& function);
 };
 
-class ButtonBoxWindow : public Gtk::Window
-{
-public:
-    ButtonBoxWindow(const char* name);
-
-    virtual ~ButtonBoxWindow();
-
-    void add_window(Gtk::Window& window);
-
-    void add_func(const char* name, const boost::function<void()>& func);
-
-    void add_thread(const char* name, const boost::function<bool()>& func);
-
-    void add_toggle(const char* name, Property<bool>& flag);
-    void add_toggle(const char* name,
-            const boost::function<void()>& on,
-            const boost::function<void()>& off);
-    void add_toggle(const char* name, const boost::function<void(bool)>& func);
-
-    void add_file_selection(const char* name,
-            const boost::function<bool(const char*)>& function);
-
-private:
-    ButtonBox m_list;
-};
-
 }
 
 #endif
