@@ -1,4 +1,4 @@
-/* $Id$
+/* $Id: filebutton.cc 53 2004-01-12 19:17:04Z takekawa $
  * Copyright (C) 2003 Takashi Takekawa
  * This file is part of the Grs Library
  *
@@ -22,9 +22,8 @@
 
 namespace Grs {
 
-FileButton::FileButton(const char* name,
-        const boost::function<bool(const char*)>& func)
-    : Gtk::Button(name), m_file(name), m_func(func)
+FileButton::FileButton(const char* name, const boost::function<bool(const char*)>& func)
+: Gtk::Button(name), m_file(name), m_func(func)
 {
     m_file.get_ok_button()->signal_clicked()
         .connect(SigC::slot(*this, &FileButton::on_ok_clicked));
